# SPDX-FileCopyrightText: 2026 Defensive Lab Agency
# SPDX-FileContributor: u039b <git@0x39b.fr>
#
# SPDX-License-Identifier: GPL-3.0-or-later


class IgnoreCacheException(Exception):
    pass


class TopicNotFoundException(Exception):
    pass
